############
Installation
############

Requirements
############

* CPython 2.7 or 2.6
* `virtualenv <https://virtualenv.pypa.io/en/stable/>`_
  (only the latest 2 versions are officially supported and tested)
  15.1.x, 15.0.x

.. note::

    As Python 2.6 is no longer being maintained,
    terrarium's support for 2.6
    is officially deprecated
    and will be removed in a future version.

Install using pip
#################

.. code-block:: shell-session

    $ pip install terrarium

Upgrade using pip
#################

.. code-block:: shell-session

    $ pip install -U terrarium

